==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/es/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Seguidores de <strong>usuario</strong>',
    '<strong>Following</strong>' => '<strong>Siguiendo</strong> a usuario',
    '<strong>Group</strong> members - {group}' => '<strong>Miembros</strong> del Grupo - {group}',
    '<strong>Member</strong> in these spaces' => '<strong>Miembros</strong> en estos espacios',
    '<strong>Member</strong> of these Spaces' => '<strong>Miembro</strong> de estos Espacios',
    '<strong>People</strong>' => '<strong>Personas</strong>',
    '<strong>User</strong> tags' => 'Etiquetas de <strong>usuario</strong>',
    'All' => 'Todos',
    'Allows access to your about page with personal information' => 'Permite accesar a tu página Acerca de con información personal',
    'Any' => 'Cualquiera',
    'Auth Mode' => 'Modo de autenticación',
    'Basic Settings' => 'Ajustes básicos',
    'Change Email' => 'Cambiar correo',
    'Change Password' => 'Cambiar clave',
    'Change Username' => 'Cambiar nombre de usuario',
    'Confirm new password' => 'Confirmar clave',
    'Connect account' => 'Conectar cuenta',
    'Connected Accounts' => 'Cuentas Conectadas',
    'Connected accounts' => 'Cuentas conectadas',
    'Created at' => 'Creado el',
    'Created by' => 'Creado por',
    'Current password' => 'Clave actual',
    'Currently in use' => 'Actualmente en uso',
    'Default Group' => 'Grupo predeterminado',
    'Default Space' => 'Espacio predeterminado',
    'Delete' => 'Borrar',
    'Delete Account' => 'Borrar cuenta',
    'Description' => 'Descripción',
    'Disconnect account' => 'Desconectar cuenta',
    'E-Mail is already in use! - Try forgot password.' => '¡Este correo electrónico ya está en uso! - Prueba a restablecer tu contraseña.',
    'Email' => 'Correo electrónico',
    'Enable Notifications' => 'Activar notificaciones',
    'Find people by their profile data or user tags' => 'Encontrar personas por los datos de su perfil o etiquetas de usuario',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Force password change upon first login' => 'Obligar a cambiar la clave la primera vez que se acceda',
    'Force password change upon next login' => 'Obligar a cambiar la clave la siguiente vez que se acceda',
    'Friends' => 'Amigos',
    'General' => 'General',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Aquí puede conectar a un proveedor de servicios externo para utilizar servicios externos como un solo registro o autenticación.',
    'Language' => 'Idioma',
    'Last Login' => 'Último registro',
    'Manager' => 'Administrador',
    'Missing E-Mail Attribute from AuthClient.' => 'Falta el atributo E-Mail en AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Falta el atributo ID AuthClient en AuthClient.',
    'Modules' => 'Módulos',
    'My Account' => 'Mi Cuenta',
    'Name' => 'Nombre',
    'New password' => 'Nueva contraseña',
    'No results found!' => 'Sin resultados encontrados!',
    'No users found.' => 'No se encontraron usuarios.',
    'Notifications' => 'Notificaciones',
    'Password' => 'Contraseña',
    'Password changed' => 'Clave cambiada',
    'Password needs to be at least {chars} characters long.' => 'La contraseña tiene que tener al menos {chars} caracteres.',
    'Pending Requests' => 'Solicitudes pendientes',
    'People' => 'Gente',
    'Permission' => 'Permiso',
    'Profile' => 'Perfil',
    'Profile posts only' => 'Sólo entradas de perfil',
    'Register now and participate!' => '¡Regístrese ahora y participe!',
    'Search...' => 'Buscar...',
    'Security' => 'Seguridad',
    'Send invite' => 'Enviar invitación',
    'Settings' => 'Ajustes',
    'Show At Registration' => 'Mostrar en Registro',
    'Show all content' => 'Mostrar todo el contenido',
    'Sign in' => 'Iniciar sesión',
    'Sign in / up' => 'Entrar / Registrarse',
    'Sign up' => 'Registrarse',
    'Sign up now' => 'Registrarse ahora',
    'Sort order' => 'Ordenado por',
    'Source' => 'Fuente',
    'Status' => 'Estado',
    'Tags' => 'Etiquetas',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Unknown user status!' => 'Estado del usuario desconocido.',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Intentos de inicio de sesión fallidos desde el último inicio de sesión: {failedLoginAttemptsCount}',
    'Updated at' => 'Actualizado el',
    'Updated by' => 'Actualizado por',
    'User' => 'Usuario',
    'User Group' => 'Grupo de usuarios',
    'User has been invited.' => 'El usuario ha sido invitado.',
    'Username' => 'Nombre de usuario',
    'Username contains invalid characters.' => 'Ese nombre de usuario contiene caracteres no válidos.',
    'View your about page' => 'Ver tu página Acerca de',
    'Visibility' => 'Visibilidad',
    'Visible' => 'Visible',
    'Welcome to %appName%' => 'Bienvenido a %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Bienvenido a %appName%.Por favor, haz clic en el botón de abajo para proceder a registrarte.',
    'You got an invite' => 'Tiene una invitación',
    'You\'re not registered.' => 'Usted no está registrado.',
    'You\'ve been invited to join {space} on {appName}' => 'Ha sido invitado a unirse a {space} en {appName}',
    'Your account is disabled!' => '¡Su cuenta está deshabilitada!',
    'Your account is not approved yet!' => '¡Su cuenta todavía no ha sido aprobada!',
    'Your are already logged in! - Logout first!' => '¡Ya estás autenticado! ¡Antes tienes que salir!',
    'Your new password must not be equal your current password!' => 'Tu nueva clave no debe ser igual a la actual',
    'invited you to join {name}.' => 'le ha invitado a unirse a {name}.',
    'invited you to join {space} on {name}.' => 'le ha invitado a unerse a {space} en {name}.',
    'or' => 'o',
    'Allow users to mention you' => '',
    'Invited by' => '',
    'Mentioning' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/user/messages/es/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Seguidores de <strong>usuario</strong>',
    '<strong>Following</strong>' => '<strong>Siguiendo</strong> a usuario',
    '<strong>Member</strong> in these spaces' => '<strong>Miembros</strong> en estos espacios',
    '<strong>Member</strong> of these Spaces' => '<strong>Miembro</strong> de estos Espacios',
    '<strong>People</strong>' => '<strong>Personas</strong>',
    '<strong>User</strong> tags' => 'Etiquetas de <strong>usuario</strong>',
    'All' => 'Todos',
    'Allow users to mention you' => 'Permitir que otros usuarios te mencionen.',
    'Allows access to your about page with personal information' => 'Permite accesar a tu página Acerca de con información personal',
    'Any' => 'Cualquiera',
    'Auth Mode' => 'Modo de autenticación',
    'Basic Settings' => 'Ajustes básicos',
    'Change Email' => 'Cambiar correo',
    'Change Password' => 'Cambiar clave',
    'Change Username' => 'Cambiar nombre de usuario',
    'Confirm new password' => 'Confirmar clave',
    'Connect account' => 'Conectar cuenta',
    'Connected Accounts' => 'Cuentas Conectadas',
    'Connected accounts' => 'Cuentas conectadas',
    'Created at' => 'Creado el',
    'Created by' => 'Creado por',
    'Current password' => 'Clave actual',
    'Currently in use' => 'Actualmente en uso',
    'Default Group' => 'Grupo predeterminado',
    'Default Space' => 'Espacio predeterminado',
    'Delete' => 'Borrar',
    'Delete Account' => 'Borrar cuenta',
    'Description' => 'Descripción',
    'Did you forget your password?' => '¿Ha olvidado su clave?',
    'Disconnect account' => 'Desconectar cuenta',
    'Edit' => 'Editar',
    'Email' => 'Correo electrónico',
    'Enable Notifications' => 'Activar notificaciones',
    'Find people by their profile data or user tags' => 'Encontrar personas por los datos de su perfil o etiquetas de usuario',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Following (User)' => 'Usuarios seguidos',
    'Force password change upon first login' => 'Obligar a cambiar la clave la primera vez que se acceda',
    'Force password change upon next login' => 'Obligar a cambiar la clave la siguiente vez que se acceda',
    'Friends' => 'Amigos',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Aquí puede conectar a un proveedor de servicios externo para utilizar servicios externos como un solo registro o autenticación.',
    'If this wasn\'t you, you can disregard this message.' => 'Si no era usted, puede ignorar este mensaje.',
    'Invite by email' => 'Invitar por correo electrónico',
    'Invite by link' => 'Invitar mediante un enlace',
    'Invite new people' => 'Invitar a nuevas personas',
    'Invited by' => 'Invitado por',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Parece que ha hecho clic en un enlace de restauración de clave inválido. Por favor vuelva a intentarlo.',
    'Language' => 'Idioma',
    'Last Login' => 'Último registro',
    'Mentioning' => 'Mencionando',
    'Missing E-Mail Attribute from AuthClient.' => 'Falta el atributo E-Mail en AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Falta el atributo ID AuthClient en AuthClient.',
    'Modules' => 'Módulos',
    'My Account' => 'Mi Cuenta',
    'Name' => 'Nombre',
    'New password' => 'Nueva contraseña',
    'No results found!' => 'Sin resultados encontrados!',
    'No users found.' => 'No se encontraron usuarios.',
    'Notifications' => 'Notificaciones',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Password' => 'Contraseña',
    'Password changed' => 'Clave cambiada',
    'Password needs to be at least {chars} characters long.' => 'La contraseña tiene que tener al menos {chars} caracteres.',
    'Password recovery' => 'Recuperar clave',
    'Pending Requests' => 'Solicitudes pendientes',
    'People' => 'Gente',
    'Permission' => 'Permiso',
    'Profile' => 'Perfil',
    'Profile posts only' => 'Sólo entradas de perfil',
    'Register now and participate!' => '¡Regístrese ahora y participe!',
    'Search...' => 'Buscar...',
    'Security' => 'Seguridad',
    'Settings' => 'Ajustes',
    'Show At Registration' => 'Mostrar en Registro',
    'Show all content' => 'Mostrar todo el contenido',
    'Sign in' => 'Iniciar sesión',
    'Sign in / up' => 'Entrar / Registrarse',
    'Sign up' => 'Registrarse',
    'Sign up now' => 'Registrarse ahora',
    'Sort order' => 'Ordenado por',
    'Source' => 'Fuente',
    'Status' => 'Estado',
    'Tags' => 'Etiquetas',
    'The secure link has been copied in your clipboard!' => '¡El enlace seguro se ha copiado al portapapeles!',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Unknown user status!' => 'Estado del usuario desconocido.',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Intentos de inicio de sesión fallidos desde el último inicio de sesión: {failedLoginAttemptsCount}',
    'Updated at' => 'Actualizado el',
    'Updated by' => 'Actualizado por',
    'User' => 'Usuario',
    'User Group' => 'Grupo de usuarios',
    'User has been invited.' => 'El usuario ha sido invitado.',
    'Username' => 'Nombre de usuario',
    'Username contains invalid characters.' => 'Ese nombre de usuario contiene caracteres no válidos.',
    'View your about page' => 'Ver tu página Acerca de',
    'Visibility' => 'Visibilidad',
    'Visible' => 'Visible',
    'Welcome to %appName%' => 'Bienvenido a %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Bienvenido a %appName%.Por favor, haz clic en el botón de abajo para proceder a registrarte.',
    'Whenever a user follows another user.' => 'Cuando un usuario sigue a otro usuario.',
    'You got an invite' => 'Tiene una invitación',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Usted ha tratado de registrar una cuanta en %appName%, pero ya existe una cuenta asociada a esa dirección de correo electrónico.',
    'You\'re not registered.' => 'Usted no está registrado.',
    'You\'ve been invited to join {space} on {appName}' => 'Ha sido invitado a unirse a {space} en {appName}',
    'Your account is disabled!' => '¡Su cuenta está deshabilitada!',
    'Your account is not approved yet!' => '¡Su cuenta todavía no ha sido aprobada!',
    'Your are already logged in! - Logout first!' => '¡Ya estás autenticado! ¡Antes tienes que salir!',
    'Your new password must not be equal your current password!' => 'Tu nueva clave no debe ser igual a la actual',
    'invited you to join {name}.' => 'le ha invitado a unirse a {name}.',
    'invited you to join {space} on {name}.' => 'le ha invitado a unerse a {space} en {name}.',
    'or' => 'o',
    'Advanced Profile Search' => '',
    'Block user' => '',
    'Group Manager(s)' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
    'The user has been blocked for you.' => '',
    'The user has been unblocked for you.' => '',
    'Unblock user' => '',
];
